@@ -930,10 +930,10 @@ def print_constraints(instance_dict: Dict[str, str], output: TextIO) -> None:
   output.write('puts "applying partitioning constraints generated by tlpc"\n')
   for pblock, modules in directive_dict.items():
     output.write(f'add_cells_to_pblock [get_pblocks {pblock}] '
-                 '[get_cells -hierarchical -regex {\n')
+                 '[get_cells -regex {\n')
     for module in modules:
       module = module.replace('[', r'\\[').replace('.', r'\\.')
-      output.write(f'  (.*/)?{module}\n')
+      output.write(f'  pfm_top_i/dynamic_region/.*/inst/{module}\n')
     output.write('}]\n')
 
 
